betty.copyright_notice package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.copyright_notice package

## Submodules

- betty.copyright_notice.copyright_notices module
  - `ProjectAuthor`
    - `ProjectAuthor.__init__()`
    - `ProjectAuthor.new_for_project()`
    - `ProjectAuthor.summary`
    - `ProjectAuthor.text`
  - `PublicDomain`
    - `PublicDomain.summary`
    - `PublicDomain.text`

## Module contents

Provide copyright notices.

betty.copyright_notice.COPYRIGHT_NOTICE_REPOSITORY: PluginRepository[CopyrightNotice] = <betty.plugin.entry_point.EntryPointPluginRepository object>

  The copyright notice plugin repository.

  Read more about Copyright notice plugins.

class betty.copyright_notice.CopyrightNotice

  Bases: `Plugin`

  A copyright notice.

  Read more about Copyright notice plugins.

  To test your own subclasses, use `betty.test_utils.copyright_notice.CopyrightNoticeTestBase`.

  abstract property summary: Localizable

    The copyright summary.

  abstract property text: Localizable

    The full copyright text.

  property url: Localizable | None

    The URL to an external human-readable resource with more information about this copyright.